import dzzd.*;

public class MainIntro extends Render3DCallBack
{
	final public static int P4D_NONE=0;
	final public static int P4D_LINEAR=1;	
	final public static int P4D_COSIN=2;	
	final public static int P4D_CUBIC=3;		

	private String baseURL;
	private boolean allObjectLoaded;
	private IPoint4D animRotation;
	private IPoint4D animPosition;
	private long startTime;

	MainIntro(String baseURL)
	{
		this.baseURL=baseURL;
		this.allObjectLoaded=false;
		this.animRotation=DzzD.newPoint4D();
		this.animPosition=DzzD.newPoint4D();
		this.startTime=System.currentTimeMillis();
	}	
	
	public void render3DstartCallBack(IRender3D render)
	{
		render.setBackgroundColor(0x000000);
		render.clearScene3D();
		render.loadScene3DFrom3DS(this.baseURL+"3DS/","3DZZD.3DS");
		render.getCamera3DById(0).setFOV(45);
	}
	
	public void render3DStart(IRender3D render)
	{
		IMesh3D loading=render.getMesh3DByName("3DZZD.3DS");
		if(!this.allObjectLoaded)
		{
			if(loading!=null)
			{
				this.allObjectLoaded=true;
				render.setCurrentCameraById(0);
				loading.getPosition().setZ(600);
				IPoint3D rot=loading.getRotation();
				double rx=rot.getX();
				double ry=rot.getZ();
				double rz=rot.getY();
				IPoint3D pos=loading.getPosition();
				double px=pos.getX();
				double py=pos.getY();
				double pz=pos.getZ();				
				
				animRotation.addKey(rx,ry,rz,0,P4D_CUBIC);
				animRotation.addKey(rx+4.0*Math.PI,ry+2.0*Math.PI,rz,5000,P4D_CUBIC);
				animRotation.setLoop(5000);
				animRotation.start();
				
				animPosition.addKey(px,py,pz,0,P4D_CUBIC);
				animPosition.addKey(px+10,py+10,pz+100,1000/2,P4D_CUBIC);
				animPosition.addKey(px+10,py-10,pz-100,2000/2,P4D_CUBIC);
				animPosition.addKey(px-10,py-10,pz+100,3000/2,P4D_CUBIC);
				animPosition.addKey(px-10,py+10,pz,4000/2,P4D_CUBIC);
				animPosition.addKey(px,py,pz,5000/2,P4D_CUBIC);
				animPosition.addKey(px+10,py+10,pz+100,6000/2,P4D_CUBIC);
				animPosition.setLoop(5000/2);
				animPosition.start();
				
			}
		}
		else
		{
			animRotation.play();
			animPosition.play();
			loading.getRotation().copy(animRotation);
			loading.getPosition().copy(animPosition);
		}
	}
	
	public void render3DEnd(IRender3D render)
	{
		int time=(int)(System.currentTimeMillis()-this.startTime);
		if(time>6000)
			render.setRender3DCallBack(new MainLoading(this.baseURL));
	}
	
	
		
	
}