import dzzd.*;

public class MainLoading extends Render3DCallBack
{
	final public static int P4D_NONE=0;
	final public static int P4D_LINEAR=1;	
	final public static int P4D_COSIN=2;	
	final public static int P4D_CUBIC=3;		

	private String baseURL;
	private boolean allObjectLoaded;
	private IPoint4D animRotation;
	private IPoint4D animPosition;
	
	MainLoading(String baseURL)
	{
		this.baseURL=baseURL;
		this.allObjectLoaded=false;
		this.animRotation=DzzD.newPoint4D();
		this.animPosition=DzzD.newPoint4D();
	}	
	
	public void render3DstartCallBack(IRender3D render)
	{
		render.setBackgroundColor(0x000000);
		render.clearScene3D();
		render.loadScene3DFrom3DS(this.baseURL+"3DS/","LOADING.3DS");
		render.getCamera3DById(0).setFOV(45);
	}
	
	public void render3DStart(IRender3D render)
	{
		IMesh3D loading=render.getMesh3DByName("LOADING.3DS");
		if(!this.allObjectLoaded)
		{
			if(loading!=null)
			{
				render.loadScene3DFrom3DS(this.baseURL+"3DS/","MENU.3DS");
				this.allObjectLoaded=true;
				render.setCurrentCameraById(0);
				loading.getPosition().setZ(1000);
				IPoint3D rot=loading.getRotation();
				double rx=rot.getX();
				double ry=rot.getZ();
				double rz=rot.getY();
				IPoint3D pos=loading.getPosition();
				double px=pos.getX();
				double py=pos.getY();
				double pz=pos.getZ();				
				
				animRotation.addKey(rx,ry,rz,0,P4D_CUBIC);
				animRotation.addKey(rx+Math.PI/3.0,ry+Math.PI/3.0,rz,1000,P4D_CUBIC);
				animRotation.addKey(rx-Math.PI/3.0,ry-Math.PI/3.0,rz,2000,P4D_CUBIC);
				animRotation.addKey(rx,ry,rz,3000,P4D_CUBIC);
				animRotation.addKey(rx+Math.PI/3.0,ry+Math.PI/3.0,rz,4000,P4D_CUBIC);
				animRotation.setLoop(3000);
				animRotation.start();
				
				animPosition.addKey(px,py,pz,0,P4D_CUBIC);
				animPosition.addKey(px+100,py+100,pz+500,1000,P4D_CUBIC);
				animPosition.addKey(px+100,py-100,pz-200,2000,P4D_CUBIC);
				animPosition.addKey(px-100,py-100,pz+500,3000,P4D_CUBIC);
				animPosition.addKey(px-100,py+100,pz,4000,P4D_CUBIC);
				animPosition.addKey(px,py,pz,5000,P4D_CUBIC);
				animPosition.addKey(px+100,py+100,pz+500,6000,P4D_CUBIC);
				animPosition.setLoop(5000);
				animPosition.start();
				
			}
		}
		else
		{
			animRotation.play();
			animPosition.play();
			loading.getRotation().copy(animRotation);
			loading.getPosition().copy(animPosition);
		}
	}
	
	public void render3DEnd(IRender3D render)
	{
		IMesh3D menu=render.getMesh3DByName("MENU.3DS");
		if(menu!=null)
		{
			IMesh3D loading=render.getMesh3DByName("LOADING.3DS");
			render.removeMesh3DById(loading.getId());
			render.setRender3DCallBack(new MainMenu(this.baseURL));
		}
	}
		
	
}