import dzzd.*;
import java.awt.Cursor;

public class MainMenu extends Render3DCallBack
{
	final public static int P4D_NONE=0;
	final public static int P4D_LINEAR=1;	
	final public static int P4D_COSIN=2;	
	final public static int P4D_CUBIC=3;		
	
	private String baseURL;
	private IPoint4D animLight;
	private int currentMenu;
	private int lastMenu;
	private IPoint4D animRot;
	
	
	
	MainMenu(String baseURL)
	{
		this.baseURL=baseURL;
		this.currentMenu=0;
		this.lastMenu=0;
		this.animLight=DzzD.newPoint4D();
		this.animRot=DzzD.newPoint4D();		
		
	}	
	
	public void render3DstartCallBack(IRender3D render)
	{
		render.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		render.setBackgroundColor(0x000000);
		render.getCamera3DByName("CameraMenu").setFOV(45);
		render.setCurrentCameraByName("CameraMenu");
		IPoint3D rot=render.getLight3DById(0).getRotation();
		rot.setX(0);
		rot.setY(Math.PI*0.5);
		rot.setZ(0);
		double rx=rot.getX();
		double ry=rot.getY();
		double rz=rot.getZ();
		animLight.addKey(rx,ry,rz,0,P4D_CUBIC);
		
		animLight.addKey(rx-Math.PI*0.5,ry,rz,2500,P4D_CUBIC);
		
		animLight.addKey(rx,ry,rz,5000,P4D_CUBIC);
		
		animLight.setLoop(5000);
		animLight.start();
		
		animRot.addKey(0+Math.PI*0.5,0,0,0,P4D_LINEAR);
		animRot.addKey(2.0*Math.PI+Math.PI*0.5,0,0,2000,P4D_LINEAR);		
		animRot.setLoop(2000);
		
		this.setMenu(render);
		
						
	}
	
	public void render3DStart(IRender3D render)
	{
		animLight.play();
		render.getLight3DById(0).getRotation().copy(animLight);
		
		
		int idObject=render.getRenderedMesh3DIdAt(render.getMouseX(),render.getMouseY());
		if(idObject!=-1)
		{
			IMesh3D obj=render.getMesh3DById(idObject);
			this.lastMenu=this.currentMenu;
			if(obj.getName().equals("intro"))	
				this.currentMenu=0;
			if(obj.getName().equals("start"))	
				this.currentMenu=1;
			if(obj.getName().equals("option"))	
				this.currentMenu=2;				
			if(this.lastMenu!=this.currentMenu)
				this.setMenu(render);
			
		}

		this.animRot.play();
	
		switch(this.currentMenu)
		{
			case 0:	
				IMesh3D intro=render.getMesh3DByName("intro");
				intro.getRotation().copy(this.animRot);
			break;
			case 1:	
				IMesh3D start=render.getMesh3DByName("start");
				start.getRotation().copy(this.animRot);
			break;
			case 2:	
				IMesh3D option=render.getMesh3DByName("option");
				option.getRotation().copy(this.animRot);
			break;
		}						
	}
	
	private void setMenu(IRender3D render)
	{
		IMesh3D intro=render.getMesh3DByName("intro");
		intro.getRotation().set(Math.PI*0.5,0,0);
		IMesh3D start=render.getMesh3DByName("start");
		start.getRotation().set(Math.PI*0.5,0,0);
		IMesh3D option=render.getMesh3DByName("option");
		option.getRotation().set(Math.PI*0.5,0,0);

		IMaterial mintro=render.getMaterialByName("intro");
		IMaterial mstart=render.getMaterialByName("start");
		IMaterial moption=render.getMaterialByName("option");
		mintro.setDiffuseColor(0xFF0000);
		mstart.setDiffuseColor(0xFF0000);
		moption.setDiffuseColor(0xFF0000);
		switch(this.currentMenu)
		{
			case 0:	
				mintro.setDiffuseColor(0x0000FF);
			break;
			case 1:	
				mstart.setDiffuseColor(0x0000FF);
			break;
			case 2:	
				moption.setDiffuseColor(0x0000FF);
			break;
		}			
		animRot.start();		
	}
		
	
}